% Secant method to find a roof of a function f with initial guesses
% x0 and x1
%
%  YOUR NAME
%
% Inputs
%  f	   function we want to find the root of
%  x0	   initial iterate
%  x1	   initial iterate
%  tol     desired tolerance or precision
%  maxit   maximum  number of iterations
%
% Outputs
%  xs      iteration history, last iterate is xs(end)

function xs = secant(f,x0,x1,tol,maxit)

 % TO BE COMPLETED
